Commentator breaks down how Trump’s speech could affect elections - YouTube
Description: Enjoy the videos and music you love, upload original content, and share it all with friends, family, and the world on YouTube.
Keywords: video, sharing, camera phone, video phone, free, upload

#

•

###

###

NaN / NaN
Back
Sign in
Home
Home
Explore
Explore
Shorts
Shorts
Subscriptions
Subscriptions
Library
Library
History
History
All Live Gaming Music Quarterbacks Game shows Tools Bat-and-Ball Sports History Aircrafts Trucks Gadgets Basketball Comedy Eating New-Age Music Action-adventure games Cars Conversation Pop Music Recently uploaded
Now playing

### what happened

IShowSpeed
IShowSpeed
Verified
•
43K watching
LIVE
10:32:36 Now playing

### CCR, Scorpions, GNR, Bon Jovi, U2, Led Zeppelin, Aerosmith ?? Rock Ballads 70's 80's 90's

Music In Paradise
Music In Paradise
Verified
•
9M views Streamed 1 year ago
27:44 Now playing

### Diary of a Wimpy Kid: Freshman Year | A Parody Film

The Fruit Jar
The Fruit Jar
•
1M views 5 months ago
41:27 Now playing

### The Oakland, California Homeless Problem is Beyond Belief

Nick Johnson
Nick Johnson
Verified
•
9.6M views 9 months ago

##
Shorts

### Millie Bobby Brown on the Stranger Things S4 Set #shorts

•
12M views

### This car is MIND blowing ?

•
26M views

### Puppy Drums #shorts

•
24M views

### Big Cat Chin Scratches & Boops! AMAZING

•
16M views

### Yoga stretch training || Gymnastics and Contortion tutorial || Stretch Training

•
15M views

### How The Animals Eat On Thanksgiving ?? #shorts #thanksgiving

•
173M views

### We just made you a berry delicious smoothie ? #ThatLittlePuff #puffknowsbetter #shorts

•
101M views

### No Way This Happened ? #Shorts

•
225M views
20:10 Now playing

### Tik Toks That Left Me In Tears ??

TikTok Victory
TikTok Victory
Verified
•
2.7M views 3 months ago
11:54:59 Now playing

### Gentle healing music for health and calming the nervous system, deep relaxation #8

Love YourSelf
Love YourSelf
Verified
•
2.4M views Streamed 4 months ago

##
Trending

21:26 Now playing

### Is Linus Tech Tips Screwdriver Best? LTT vs Wera, Snap On, PB Swiss, Milwaukee, MegaPro, GearWrench

Project Farm
Project Farm
Verified
•
912K views 2 days ago
22:54 Now playing

### I Hitchhiked a Cargo Ship to Wherever it’s Going

Yes Theory
Yes Theory
Verified
•
1.1M views 2 days ago
22:05 Now playing

### The First Punic War - OverSimplified (Part 2)

OverSimplified
OverSimplified
Verified
•
4.6M views 4 days ago
18:58 Now playing

###
TV Theories S1 E1
Film Theory: Someone PLEASE Help Elmo! (Sesame Street)

The Film Theorists
The Film Theorists
Verified
•
2.3M views 2 days ago
12:54 Now playing

### Uncle Roger LOVE INSANE EGG FRIED RICE TECHNIQUE (ft. Adam Liaw)

mrnigelng
mrnigelng
Verified
•
2.3M views 2 days ago
33:15 Now playing

### Pokemon but if something can go wrong, it does.

SmallAnt
SmallAnt
Verified
•
1M views 2 days ago
23:30 Now playing

### From Handheld to Console - Scott The Woz

Scott The Woz
Scott The Woz
Verified
•
547K views 19 hours ago
3:26 Now playing

### BLACK VEIL BRIDES - Saviour II (Official Music Video)

Sumerian Records
Sumerian Records
•
111K views 15 hours ago
6:59 Now playing

### Race Highlights | 2022 Dutch Grand Prix

FORMULA 1
FORMULA 1
Verified
•
5.1M views 2 days ago
4:11 Now playing

### Pick a Video Game Item

Ice Cream Sandwich
Ice Cream Sandwich
Verified
•
662K views 2 days ago
3:06 Now playing

### Silk Boss - Sorry (Official Music Video)

Silk Boss Official
Silk Boss Official
Official Artist Channel
•
812K views 2 days ago
2:35 Now playing

### NBA YoungBoy - Purge Me

YoungBoy Never Broke Again
YoungBoy Never Broke Again
Official Artist Channel
•
2.2M views 1 day ago
33:39 Now playing

### Inside The Dominican Republic's Most Dangerous Hood ??

Kurt Caz
Kurt Caz
Verified
•
10M views 1 year ago
11:59 Now playing

### People Being Idiots: Stupidity At Its Best | FailArmy

FailArmy
FailArmy
Verified
•
15M views 1 month ago
Featured
Discover your next favorite favorites
They’re the study spot scouts, bead lovers, and roadway wanderers the internet was made for. Meet YouTube’s Creators on the Rise.
explore more
27:43 Now playing

### 100 Interesting Animal Moments Caught On Camera

Wicked Wombat
Wicked Wombat
•
10M views 3 months ago
11:54:59 Now playing

### IBIZA SUMMER MIX 2021 ↠ Paradise, Thailand, Hawaii, Greece, ISLANDS ? Feeling Me #77

Green Sound
Green Sound
•
3.4M views Streamed 9 months ago
8:19:49 Now playing

### Post Malone, Maroon 5, Adele, Taylor Swift, Ed Sheeran, Shawn Mendes, Pop Hits 2020 Part 6

Music Library
Music Library
•
1.6M views Streamed 2 years ago
1:57:12 Now playing

### What A 15 Year Old Mass Killer Looks Like

EXPLORE WITH US
EXPLORE WITH US
Verified
•
12M views 2 months ago
15:53 Now playing

### Dirtiest Cheap Shots in Football History ᴴᴰ

the CNtaco
the CNtaco
•
10M views 2 years ago
42:40 Now playing

### 100 Days, But I Can’t Leave This CHUNK…

aCookieGod
aCookieGod
Verified
•
8.1M views 2 months ago
3:56:41 Now playing

### 4 Hours of Music For Studying, Concentration And Work - Ambient Study Music to Concentrate

Quiet Quest - Study Music
Quiet Quest - Study Music
Verified
•
4M views 9 months ago
24:01 Now playing

### Border Security Australia's Front Line - Full Episode

Border Force Australia
Border Force Australia
•
958K views 1 month ago
27:20 Now playing

### We Opened A Fake McDonalds

Beta Squad
Beta Squad
Verified
•
4.9M views 2 weeks ago
22:38 Now playing

### Duck Dynasty: Si's Near Death Experience (S8, E7) | Full Episode

Duck Dynasty
Duck Dynasty
Verified
•
728K views 5 months ago
47:12 Now playing

### How We FOUND Kiely Rodni: MURDER or ACCIDENT?

Adventures with Purpose
Adventures with Purpose
Verified
•
1.3M views 4 days ago
11:54:59 Now playing

### Phil Collins, Elton John, Lionel Richie, George Michael, Eric Clapton - Best Soft Rock Songs EVER

SOFT ROCK MUSIC
SOFT ROCK MUSIC
•
3.9M views Streamed 1 year ago

###

•
YouTube Unaware NextNewThing v2
If playback doesn't begin shortly, try restarting your device.
You're signed out
Videos you watch may be added to the TV's watch history and influence TV recommendations. To avoid this, cancel and sign in to YouTube on your computer.
shop pOpshelf
www.popshelf.com/
Ad 1 of 2 ·
0:20
Why this ad?
5
Share
Include playlist
An error occurred while retrieving sharing information. Please try again later.
0:00
0:20
0:00 / 0:20•Watch full video

## Description

CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump’s speech in Pennsylvania. #CNN #News
Show less Show more

## Comments 3.9K

## Transcript

###

###

NaN / NaN
#CNN #News

# Commentator breaks down how Trump’s speech could affect elections

236,159 views Sep 4, 2022 CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump’s speech in Pennsylvania. #CNN #News…...more
...more
Show less
CNN
CNN
14.2M subscribers
Subscribe
Comments
3.9K
Add a comment...
#CNN #News

# Commentator breaks down how Trump’s speech could affect elections

236,159 views236K views
Sep 4, 2022
CNN
CNN
14.2M subscribers
Subscribe
CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump’s speech in Pennsylvania. #CNN #News
Show less ...more
Why this ad?
shop pOpshelf
Ad
www.popshelf.com/
Learn More

### Make doorbell cams ancient

See why this new $46 security device is selling out online
Ad
happeningtoday.co
VISIT SITE

### See video of ex-Georgia official escorting Trump operatives into election offices

CNN
CNN
•
346K views 6 hours ago
New

### Top prosecutor reveals how long a Trump PRISON SENTENCE could be

Brian Tyler Cohen
Brian Tyler Cohen
•
550K views 1 day ago
New

### Watch Morning Joe Highlights: September 6 | MSNBC

MSNBC
MSNBC
•
36K views 1 hour ago
New

### Why Lofgren says Trump’s speech was ‘weird’

CNN
CNN
•
672K views 1 day ago
New

### Attorney explains judge's comments on Trump special master ruling

CNN
CNN
•
705K views 1 day ago
New

### 'Let Him Go' Vs. 'I'd Like To Punch Him In The Face': How Biden, Trump Handle Hecklers

MSNBC
MSNBC
•
305K views 8 hours ago
New

### Liz Truss Gives First Speech as UK Prime Minister

Bloomberg Quicktake: Now
Bloomberg Quicktake: Now
•
192 views 33 minutes ago
New

### Trump Warns Of Backlash To Search, Calls FBI, DOJ 'Vicious Monsters'

MSNBC
MSNBC
•
400K views 1 day ago
New

### Sen. Kennedy: Biden's speech was a cynical attempt to fill our heads with stupid

Fox News
Fox News
•
1.7M views 4 days ago
New

### Every President's Education

Mr. Beat
Mr. Beat
•
1.1M views 10 months ago

### Tamara Keith and Amy Walter on Trump investigation, Biden's warnings, resurgence of unions

PBS NewsHour
PBS NewsHour
•
99K views 21 hours ago
New

### Beto FLIPS Trump voters in STUNNING town hall appearance

Brian Tyler Cohen
Brian Tyler Cohen
•
1M views 2 weeks ago

### Trevor Noah: The 60 Minutes Interview

60 Minutes
60 Minutes
•
1.9M views 2 months ago

### Democrat in MOST FLIPPABLE district in America issues perfect takedown of Republican opponent

Brian Tyler Cohen
Brian Tyler Cohen
•
26K views 2 hours ago
New

### How Amazon Changed Whole Foods, Five Years Later

CNBC
CNBC
•
1.1M views 12 days ago

### Trump’s lawyer makes accidental ADMISSION on air, screws Trump over

Brian Tyler Cohen
Brian Tyler Cohen
•
745K views 2 days ago
New

## Top news

5:20 Now playing

### Sarah Palin loses special election for Alaska’s House seat to native Democrat

CNN
CNN
Verified
•
677K views 5 days ago
CNN
CNN
Verified
In an attempt to gain a political comeback, former Alaskan Governor Sarah Palin lost in a special election for a House ... In an attempt to gain a political comeback, former Alaskan Governor Sarah Palin lost in a special election for a House ...
From the video description
New
CC
2:53 Now playing

### Democrat Peltola Defeats Palin In Special Alaska House Race, NBC News Projects

MSNBC
MSNBC
Verified
•
731K views 5 days ago
MSNBC
MSNBC
Verified
MSNBC delivers breaking news, in-depth analysis of politics headlines, as well as commentary and informed perspectives. MSNBC delivers breaking news, in-depth analysis of politics headlines, as well as commentary and informed perspectives.
From the video description
New
CC
9:58 Now playing

### Commentator breaks down how Trump’s speech could affect elections

CNN
CNN
Verified
•
236K views 1 day ago
CNN
CNN
Verified
CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump's speech ... CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump's speech ...
From the video description
New
CC
+7 more
2:41 Now playing

### UK Prime Minister Election 2022 | Rishi Sunak And Liz Truss Latest News | UK PM Race | News18

CNN-News18
CNN-News18
Verified
•
41K views 1 day ago
CNN-News18
CNN-News18
Verified
UK Prime Minister Election 2022 | Rishi Sunak And Liz Truss Latest News | UK PM Race | News18 UK will be getting a new PM ... UK Prime Minister Election 2022 | Rishi Sunak And Liz Truss Latest News | UK PM Race | News18 UK will be getting a new PM ...
From the video description
New
2:49 Now playing

### Battleground 2022: Are Voter Opinions Shifting Ahead Of Midterm Elections?

CBS Miami
CBS Miami
Verified
•
7.6K views 8 days ago
CBS Miami
CBS Miami
Verified
#cbsnewsmiami #politics #news #election #elections #election2022 #2022election #democrat #democrats #republican ... #cbsnewsmiami #politics #news #election #elections #election2022 #2022election #democrat #democrats #republican ...
From the video description
9:58 Now playing

### Commentator breaks down how Trump’s speech could affect elections

CNN
CNN
Verified
•
236K views 1 day ago
CNN
CNN
Verified
CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump's speech ... CNN political commentator David Swerdlick and CNN presidential historian Tim Naftali discuss former President Trump's speech ...
From the video description
New
CC
5:14 Now playing

### How the "Trump effect" will play out in upcoming midterm elections

CBS News
CBS News
Verified
•
5.4K views 4 hours ago
CBS News
CBS News
Verified
With just nine weeks to go before the 2022 midterm elections, former President Donald Trump has placed himself at the center of ... With just nine weeks to go before the 2022 midterm elections, former President Donald Trump has placed himself at the center of ...
From the video description
New
CC
4:11 Now playing

### The 2022 election looks VERY good for Republicans

CNN
CNN
Verified
•
105K views 2 months ago
CNN
CNN
Verified
In today's episode of The Point, CNN's Chris Cillizza breaks down several projections for November elections, which predict major ... In today's episode of The Point, CNN's Chris Cillizza breaks down several projections for November elections, which predict major ...
From the video description
9:10 Now playing

### Impact of the 2022 midterm election on the Senate

CBS News
CBS News
Verified
•
18K views 5 months ago
CBS News
CBS News
Verified
Thirty-five Senate seats are up for grabs in the 2022 midterms, and with the Senate currently split 50-50, the November election is ... Thirty-five Senate seats are up for grabs in the 2022 midterms, and with the Senate currently split 50-50, the November election is ...
From the video description
CC
1:48:43 Now playing

### LIVE: Supreme Court judges rule on Kenya election challenge - BBC Africa

BBC News Africa
BBC News Africa
Verified
•
155K views Streamed 1 day ago
BBC News Africa
BBC News Africa
Verified
The Supreme Court is about to rule on Raila Odinga's challenge to the result of last month's vote. The electoral commission ... The Supreme Court is about to rule on Raila Odinga's challenge to the result of last month's vote. The electoral commission ...
From the video description
New
2:23 Now playing

### NBC Polls Shows A Mixed Landscape For 2022 Elections

NBC News
NBC News
Verified
•
18K views 2 weeks ago
NBC News
NBC News
Verified
Two months from election day and NBC News polls show a mixed picture for the 2022 landscape. Republicans now have a slim ... Two months from election day and NBC News polls show a mixed picture for the 2022 landscape. Republicans now have a slim ...
From the video description
CC
9:30 Now playing

### See video of ex-Georgia official escorting Trump operatives into election offices

CNN
CNN
Verified
•
346K views 6 hours ago
CNN
CNN
Verified
Newly obtained video by CNN shows a former Georgia Republican Coffee County official escorting two operatives, hired by an ... Newly obtained video by CNN shows a former Georgia Republican Coffee County official escorting two operatives, hired by an ...
From the video description
New
CC
2:52 Now playing

### CBS News Battleground Tracker on 2022 midterm-election estimates

CBS Mornings
CBS Mornings
Verified
•
13K views 1 month ago
CBS Mornings
CBS Mornings
Verified
CBS News elections and surveys director Anthony Salvanto joins "CBS Mornings" to discuss the Battleground Tracker's estimates ... CBS News elections and surveys director Anthony Salvanto joins "CBS Mornings" to discuss the Battleground Tracker's estimates ...
From the video description
Now playing

### Citizen TV Live

Citizen TV Kenya
Citizen TV Kenya
Verified
•
12K watching
Citizen TV Kenya
Citizen TV Kenya
Verified
CitizenTV #KenyasChoice2022. CitizenTV #KenyasChoice2022.
From the video description
LIVE

## People also watched

5:33 Now playing

### Pennsylvania Emerges As Key Battleground Ahead Of Midterm Elections

NBC News
NBC News
Verified
•
6.2K views 4 hours ago
NBC News
NBC News
Verified
With the midterm elections just two months away, Pennsylvania has emerged as a key battleground state with close races for both ... With the midterm elections just two months away, Pennsylvania has emerged as a key battleground state with close races for both ...
From the video description
New
CC
9:51 Now playing

### Sprint to the midterms sets off on unsettled political terrain

CNN
CNN
Verified
•
13K views 57 minutes ago
CNN
CNN
Verified
The two-month sprint to the midterm elections is set to take place on political terrain that is much less settled than Republicans ... The two-month sprint to the midterm elections is set to take place on political terrain that is much less settled than Republicans ...
From the video description
New
CC
47:20 Now playing

### 'Bloomberg The Open' Full Show (09/06//2022)

Bloomberg Markets and Finance
Bloomberg Markets and Finance
Verified
•
3.4K views 4 hours ago
Bloomberg Markets and Finance
Bloomberg Markets and Finance
Verified
Jonathan Ferro highlights the market-moving news you need to know heading into the opening bell on Wall Street. -------- Follow ... Jonathan Ferro highlights the market-moving news you need to know heading into the opening bell on Wall Street. -------- Follow ...
From the video description
New
CC
8:45 Now playing

### Biden sharpens message ahead of midterm elections

CBS News
CBS News
Verified
•
4.7K views 4 hours ago
CBS News
CBS News
Verified
With midterm elections just 63 days away, President Biden touted Democrats' recent congressional victories at events in the swing ... With midterm elections just 63 days away, President Biden touted Democrats' recent congressional victories at events in the swing ...
From the video description
New
CC
+6 more
7:43 Now playing

### Election results suggest red wave could sweep 2022 midterms

CBS News
CBS News
Verified
•
25K views 10 months ago
CBS News
CBS News
Verified
Republican Glenn Youngkin's victory in Virginia and a tight gubernatorial race in New Jersey are spelling trouble for the ... Republican Glenn Youngkin's victory in Virginia and a tight gubernatorial race in New Jersey are spelling trouble for the ...
From the video description
CC
9:04 Now playing

### Biden ramps up campaigning as November's midterm elections quickly approach

CBS News
CBS News
Verified
•
3.7K views 6 hours ago
CBS News
CBS News
Verified
With the midterm elections quickly approaching, President Biden is ramping up his support for Democratic candidates in hopes of ... With the midterm elections quickly approaching, President Biden is ramping up his support for Democratic candidates in hopes of ...
From the video description
New
CC
8:16 Now playing

### Midterms 2022: Tuesday Primary Election Takeaways, Results

Newsy
Newsy
Verified
•
32K views 2 months ago
Newsy
Newsy
Verified
Former President Donald Trump notched a significant victory in South Carolina, where his preferred candidate easily ousted ... Former President Donald Trump notched a significant victory in South Carolina, where his preferred candidate easily ousted ...
From the video description
CC
4:30 Now playing

### See McConnell’s telling prediction about 2022 elections

CNN
CNN
Verified
•
603K views 4 weeks ago
CNN
CNN
Verified
Senate Minority Leader Mitch McConnell (R-KY) predicted the US Senate will likely be close to a 50-50 split after the midterm ... Senate Minority Leader Mitch McConnell (R-KY) predicted the US Senate will likely be close to a 50-50 split after the midterm ...
From the video description
CC
9:04 Now playing

### 2022 Midterms Preview: Biden, Dems CRUSHING The Red Wave By Blaming ‘MAGA’ Republicans?

The Hill
The Hill
Verified
•
14K views 6 hours ago
The Hill
The Hill
Verified
Briahna Joy Gray and Robby Soave look ahead to midterms as Real Clear Politics' average forecasts Democrats as having a ... Briahna Joy Gray and Robby Soave look ahead to midterms as Real Clear Politics' average forecasts Democrats as having a ...
From the video description
New
5:06:57 Now playing

### 2022 primary coverage of the Florida, New York elections on ABC News Prime

ABC News
ABC News
Verified
•
125K views Streamed 13 days ago
ABC News
ABC News
Verified
ABCNews #yvyv #primaries Watch More on http://abcnews.go.com/ LIKE ABC News on FACEBOOK ... ABCNews #yvyv #primaries Watch More on http://abcnews.go.com/ LIKE ABC News on FACEBOOK ...
From the video description
CC
8:46 Now playing

### DNC Chairman On 2022 Midterm Elections, President Biden

MSNBC
MSNBC
Verified
•
95K views 3 weeks ago
MSNBC
MSNBC
Verified
Chairman of the DNC Jaime Harrison speaks to Symone D Sanders about what President Biden is getting done and the outlook ... Chairman of the DNC Jaime Harrison speaks to Symone D Sanders about what President Biden is getting done and the outlook ...
From the video description
CC

##
People also search for

United States Presidential election, 2020
United States presidential election, 2016
United States presidential election, 2012
2008 United States presidential election
2000 United States presidential election
SHORTS Now playing

### WATCH: Biden warns MAGA movement is a threat to democracy

PBS NewsHour
PBS NewsHour
Verified
•
61K views 3 days ago
PBS NewsHour
PBS NewsHour
Verified
In a prime-time address Thursday, President Joe Biden warned Americans that “equality and democracy are under assault” by ... In a prime-time address Thursday, President Joe Biden warned Americans that “equality and democracy are under assault” by ...
From the video description
New
3:20 Now playing

### Kenya's Disputed Election: Supreme Court Ruling

Bloomberg Markets and Finance
Bloomberg Markets and Finance
Verified
•
5.3K views 1 day ago
Bloomberg Markets and Finance
Bloomberg Markets and Finance
Verified
Kenya's Supreme Court delivers its judgment Monday in a lawsuit that seeks to overturn the results of last month's presidential ... Kenya's Supreme Court delivers its judgment Monday in a lawsuit that seeks to overturn the results of last month's presidential ...
From the video description
New